/** @file
 * @brief IPHelper class header. This class represents a Helper to get the actual IP.
 *
 *
 *
 * @copyright Intra2net AG
 * @license GPLv2
*/

#ifndef IPADDRHELPER_H
#define IPADDRHELPER_H

#include "logger.h"

#include <boost/shared_ptr.hpp>
#include <curl/curl.h>


class IPAddrHelper
{
private:

    Logger::Ptr Log;
    std::string WebcheckIpUrl;
    std::string WebcheckIpUrlAlt;
    std::string Proxy;
    int ProxyPort;
    bool UseIPv6;
    std::string Hostname;

    bool is_local(const std::string ip) const;
    std::string webcheck_ip() const;
    CURL * init_curl(std::string& curl_writedata_buff, char* curl_err_buff) const;
    int perform_curl_operation(CURL * curl_easy_handle, char* curl_err_buff, const std::string& actual_url) const;
    std::string parse_ip(const std::string& data) const;

public:

    typedef boost::shared_ptr<IPAddrHelper> Ptr;

    IPAddrHelper();

    IPAddrHelper(const Logger::Ptr _log, const std::string& _webcheck_url, const std::string& _webcheck_url_alt, const bool _use_ipv6, const std::string& _proxy, const int _proxy_port);

    ~IPAddrHelper();

    std::string dns_query(const std::string& _hostname) const;

    std::string get_actual_ip() const;

    // libcurl is a C library, so we have to make the callback member function static :-(
    static int http_receive(char *inBuffer, size_t size, size_t nmemb, std::string *outBuffer);

    void set_curl_url(CURL * curl_easy_handle, const std::string& url) const;
};

#endif
